function SC_corr = f_compute_SC_corr(SC)
% Extract the correspondent "structural correlation" matrix (SC_corr) for the input 
% structural connectome (SC), as explained in Amico & Goni, Network Neuroscience 2018.
% In summary, SC_corr contains the Pearson’s correlation coefficient between the i th and j th row of 
% the structural connectome iterated over all connected pairs. The values in this matrix range between [-1 1], 
% with negative values indicating two nodes that are connected antagonistically to the rest of the network, and
% positive indicating high similarity in their structural connections with the rest of the brain network. 
% This allows to have functional and structural connectomes in the same range ([- 1 1]).
% Input:
% -SC : 2D structural connectivity matrix (num of brain regions x num of brain regions)
% -Output
% - SC corr: "structural correlation" matrix (num of brain regions x num of brain regions, range [-1 1])
%
% example of use:
% SC_corr = f_compute_SC_corr(SC)
% Enrico Amico & Joaquin Goni, Purdue University
% version 1.0 Jan 16th 2018

N = size(SC,1);
SC_corr = zeros(N,N);
for i = 1:N-1
    for j = i+1:N
        vec_i = SC(i,:);
        vec_i([i,j])=[];
        vec_j = SC(j,:);
        vec_j([i,j])=[];
        SC_corr(i,j) = corr(vec_i',vec_j');
    end
end
SC_corr = SC_corr + SC_corr';
        